BB_filter: Filters images of brilliant blue dye tracer experiments of...

Description Usage Arguments Value Author(s) Examples

View source: R/BB_filter.R

Description

This function uses RGB thresholds to assign one of four colors to each pixel (white, dark blue, medium blue or light blue). Grey shadows are assigned white. The filter aims to make processing easier. It only works for images of snow.

Usage

1
BB_filter(rgb_image)

Arguments

rgb_image

is an array with RGB values

Value

A matrix with applied threshold where 0 is white, 1 is light blue, 2 is medium blue and 3 is dark blue

Author(s)

Johanna Bloecher, bloecher@fzp.czu.cz

Examples

1
2
3
4
5
6
7
8
## load image
library(jpeg)
# read image
raw_image <- readJPEG(system.file("example.jpg", package = "bluesnow"))
## Apply filter to raw image data
BB_filtered_image <- BB_filter(rgb_image = raw_image)
# plot filtered image
image(BB_filtered_image, col = c('white', 'lightblue', 'royalblue1', 'darkblue'))

Jorub/bluesnow documentation built on Oct. 30, 2019, 8:02 p.m.