BB_fraction: Fractions of dark, medium, light and total blue

Description Usage Arguments Value Author(s) Examples

View source: R/BB_distribution.R

Description

A simple function that reads that takes the ouput of BB_filter and calculates the proportion or fraction of total blue pixels, dark blue pixels, medium blue pixels and light blue pixels.

Usage

1
BB_fraction(filtered_image)

Arguments

filtered_image

the returned matrix of the function BB_filter with values 0, 1, 2 and 3

Value

The fraction of total, dark, medium and light blue

Author(s)

Johanna Bloecher, bloecher@fzp.czu.cz

Examples

1
2
3
4
5
library(jpeg)
raw_image <- <- readJPEG(system.file("example.jpg", package = "bluesnow"))
## Apply filter to raw image data
BB_filtered_image <- BB_filter(rgb_image = raw_image)
BB_fraction(filtered_image = BB_filtered_image)

Jorub/bluesnow documentation built on Oct. 30, 2019, 8:02 p.m.