Description Usage Arguments Value Author(s) Examples
View source: R/BB_vert_distribution.R
A simple function that processes the result of BB_filter and returns a vector with fractions over the depth of an image of a sprinkling experiment with Brilliant Blue.
1 | BB_vert_distribution(filtered_image, blue_selection = "all")
|
filtered_image |
the returned matrix of the function BB_filter with values 0, 1, 2 and 3 |
blue_selection |
the blue to consider. By default, the value for blue_selection is 'all'
|
Returns the vertical distribution of blue color as a vector.
Johanna Bloecher, bloecher@fzp.czu.cz
1 2 3 4 5 6 | library(jpeg)
raw_image <- <- readJPEG(system.file("example.jpg", package = "bluesnow"))
## Apply filter to raw image data
BB_filtered_image <- BB_filter(rgb_image = raw_image)
BB_v_dist <- BB_vert_distribution(filtered_image = BB_filtered_image, blue_selection = 'all')
plot(BB_v_dist$Depth, BB_v_dist$Bluefraction, xlab = "Depth [Pixels]", ylab = "Fraction of Blue [-]")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.